@@ -41,14 +41,12 @@
 #include "fielditem.h"
 #include "levelset.h"
 
-static const int MIN_INFO_SIZE=10;
-
 struct Theme : public KgTheme
 {
-	Theme() : KgTheme("pics/default_theme.desktop")
-	{
-		setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("pics/default_theme.svgz")));
-	}
+    Theme() : KgTheme("pics/default_theme.desktop")
+    {
+        setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("pics/default_theme.svgz")));
+    }
 };
 
 PlayField::PlayField( QObject* parent )
@@ -595,7 +593,7 @@ bool PlayField::checkDone() const
             minY = atom->fieldY();
     }
     // so origin is (minX,minY)
-    // we'll substract this origin from each atom's coords and check
+    // we'll subtract this origin from each atom's coords and check
     // if the resulting position is the same as this atom has in molecule
     foreach( AtomFieldItem* atom, m_atoms )
     {
